=====================================
Detection of non-stationary processes
=====================================

.. automodule:: elephant.change_point_detection


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: cpd
   :keyprefix: cpd-
   :style: unsrt
